Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10)

Unified Diff: components/sync/driver/startup_controller_unittest.cc

Issue 2533083002: [Sync] SyncEngine refactor part 1: interfaces. (Closed)
Patch Set: Rebase. Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/driver/startup_controller.cc ('k') | components/sync/driver/sync_api_component_factory.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/driver/startup_controller_unittest.cc
diff --git a/components/sync/driver/startup_controller_unittest.cc b/components/sync/driver/startup_controller_unittest.cc
index 8bf9e5cdd89625186e4848159f33e3c4a4482f31..6cc59d4eb270a51551cd62e22d299e5527bb913b 100644
--- a/components/sync/driver/startup_controller_unittest.cc
+++ b/components/sync/driver/startup_controller_unittest.cc
@@ -18,7 +18,7 @@
namespace syncer {
// These are coupled to the implementation of StartupController's
// GetBackendInitializationStateString which is used by about:sync. We use it
// as a convenient way to verify internal state and that the class is
// outputting the correct values for the debug string.
static const char kStateStringStarted[] = "Started";
@@ -54,7 +54,7 @@ class StartupControllerTest : public testing::Test {
void ExpectStarted() {
EXPECT_TRUE(started());
EXPECT_EQ(kStateStringStarted,
- controller()->GetBackendInitializationStateString());
+ controller()->GetEngineInitializationStateString());
}
void ExpectStartDeferred() {
@@ -63,13 +63,13 @@ class StartupControllerTest : public testing::Test {
switches::kSyncDisableDeferredStartup);
EXPECT_EQ(!deferred_start, started());
EXPECT_EQ(deferred_start ? kStateStringDeferred : kStateStringStarted,
- controller()->GetBackendInitializationStateString());
+ controller()->GetEngineInitializationStateString());
}
void ExpectNotStarted() {
EXPECT_FALSE(started());
EXPECT_EQ(kStateStringNotStarted,
- controller()->GetBackendInitializationStateString());
+ controller()->GetEngineInitializationStateString());
}
bool started() const { return started_; }
« no previous file with comments | « components/sync/driver/startup_controller.cc ('k') | components/sync/driver/sync_api_component_factory.h » ('j') | no next file with comments »
@@ -18,7 +18,7 @@
namespace syncer {
// These are coupled to the implementation of StartupController's
-// GetBackendInitializationStateString which is used by about:sync. We use it
+// GetEngineInitializationStateString which is used by about:sync. We use it
// as a convenient way to verify internal state and that the class is
// outputting the correct values for the debug string.

Powered by Google App Engine
This is Rietveld 408576698